==> igniteui-webcomponents-core-4.0.2.tgz: package/esm5/lib/DateRangeDescriptorDescription.js <==
/*
THIS INFRAGISTICS ULTIMATE SOFTWARE LICENSE  AGREEMENT ("AGREEMENT") LOCATED HERE:
https://www.infragistics.com/legal/license/igultimate-la
https://www.infragistics.com/legal/license/igultimate-eula
GOVERNS THE LICENSING, INSTALLATION AND USE OF INFRAGISTICS SOFTWARE. BY DOWNLOADING AND/OR INSTALLING AND USING INFRAGISTICS SOFTWARE:  you are indicating that you have read and understand this Agreement, and agree to be legally bound by it on behalf of the yourself and your company.
*/
import * as tslib_1 from "tslib";
import { Description } from "./Description";
import { markType } from "./type";
/**
 * @hidden
 */
var DateRangeDescriptorDescription = /** @class */ /*@__PURE__*/ (function (_super) {
    tslib_1.__extends(DateRangeDescriptorDescription, _super);
    function DateRangeDescriptorDescription() {
        var _this = _super.call(this) || this;
        _this.j = null;
        _this.g = null;
        return _this;
    }
    DateRangeDescriptorDescription.prototype.get_type = function () {
        return "DateRangeDescriptor";
    };
    Object.defineProperty(DateRangeDescriptorDescription.prototype, "type", {
        get: function () {
            return this.get_type();
        },
        enumerable: true,
        configurable: true
    });
    Object.defineProperty(DateRangeDescriptorDescription.prototype, "rangeType", {
        get: function () {
            return this.j;
        },
        set: function (a) {
            this.j = a;
            this.e("RangeType");
        },
        enumerable: true,
        configurable: true
    });
    Object.defineProperty(DateRangeDescriptorDescription.prototype, "dateRange", {
        get: function () {
            return this.g;
        },
        set: function (a) {
            this.g = a;
            this.e("DateRange");
        },
        enumerable: true,
        configurable: true
    });
    DateRangeDescriptorDescription.$t = markType(DateRangeDescriptorDescription, 'DateRangeDescriptorDescription', Description.$);
    DateRangeDescriptorDescription.__marshalByValue = true;
    DateRangeDescriptorDescription.__marshalByValueAlias = "DateRangeDescriptor";
    return DateRangeDescriptorDescription;
}(Description));
export { DateRangeDescriptorDescription };

==> igniteui-webcomponents-core-5.4.1.tgz: package/esm5/lib/DateRangeDescriptorDescription.js <==
/*
THIS INFRAGISTICS ULTIMATE SOFTWARE LICENSE  AGREEMENT ("AGREEMENT") LOCATED HERE:
https://www.infragistics.com/legal/license/igultimate-la
https://www.infragistics.com/legal/license/igultimate-eula
GOVERNS THE LICENSING, INSTALLATION AND USE OF INFRAGISTICS SOFTWARE. BY DOWNLOADING AND/OR INSTALLING AND USING INFRAGISTICS SOFTWARE:  you are indicating that you have read and understand this Agreement, and agree to be legally bound by it on behalf of the yourself and your company.
*/
import { __extends } from "tslib";
import { Description } from "./Description";
import { markType } from "./type";
/**
 * @hidden
 */
var DateRangeDescriptorDescription = /** @class */ /*@__PURE__*/ (function (_super) {
    __extends(DateRangeDescriptorDescription, _super);
    function DateRangeDescriptorDescription() {
        var _this = _super.call(this) || this;
        _this.l = null;
        _this.i = null;
        return _this;
    }
    DateRangeDescriptorDescription.prototype.get_type = function () {
        return "DateRangeDescriptor";
    };
    Object.defineProperty(DateRangeDescriptorDescription.prototype, "type", {
        get: function () {
            return this.get_type();
        },
        enumerable: false,
        configurable: true
    });
    Object.defineProperty(DateRangeDescriptorDescription.prototype, "rangeType", {
        get: function () {
            return this.l;
        },
        set: function (a) {
            this.l = a;
            this.g("RangeType");
        },
        enumerable: false,
        configurable: true
    });
    Object.defineProperty(DateRangeDescriptorDescription.prototype, "dateRange", {
        get: function () {
            return this.i;
        },
        set: function (a) {
            this.i = a;
            this.g("DateRange");
        },
        enumerable: false,
        configurable: true
    });
    DateRangeDescriptorDescription.$t = markType(DateRangeDescriptorDescription, 'DateRangeDescriptorDescription', Description.$);
    DateRangeDescriptorDescription.__marshalByValue = true;
    DateRangeDescriptorDescription.__marshalByValueAlias = "DateRangeDescriptor";
    return DateRangeDescriptorDescription;
}(Description));
export { DateRangeDescriptorDescription };
